#ifndef UTILS_H
#define UTILS


//#include <gtk/gtk.h>
//#include <hildon/hildon.h>
//#include <hildon/hildon-notification.h>


#include <Qt>
#include <QtGui>


void show_information_note (QWidget * w, const QString & t);
void show_banner (QWidget * w, const QString & t);


#endif
